@@ -49,8 +49,6 @@
 
 #include <gtk/gtk.h>
 
-#include <exo/exo.h>
-
 #include <libxfce4util/libxfce4util.h>
 
 #include <thunar-uca/thunar-uca-model.h>
@@ -80,6 +78,7 @@ typedef enum
   PARSER_COMMAND,
   PARSER_STARTUP_NOTIFY,
   PARSER_PATTERNS,
+  PARSER_RANGE,
   PARSER_DESCRIPTION,
   PARSER_DIRECTORIES,
   PARSER_AUDIO_FILES,
@@ -170,6 +169,7 @@ struct _ThunarUcaModelItem
   gchar         *command;
   guint          startup_notify : 1;
   gchar        **patterns;
+  gchar         *range;
   ThunarUcaTypes types;
 
   /* derived attributes */
@@ -192,6 +192,7 @@ typedef struct
   GString        *command;
   GString        *patterns;
   GString        *description;
+  GString        *range;
   gboolean        startup_notify;
   gboolean        description_use;
   guint           description_match;
@@ -339,6 +340,9 @@ thunar_uca_model_get_column_type (GtkTreeModel *tree_model,
     case THUNAR_UCA_MODEL_COLUMN_PATTERNS:
       return G_TYPE_STRING;
 
+    case THUNAR_UCA_MODEL_COLUMN_RANGE:
+      return G_TYPE_STRING;
+
     case THUNAR_UCA_MODEL_COLUMN_TYPES:
       return G_TYPE_UINT;
 
@@ -452,6 +456,10 @@ thunar_uca_model_get_value (GtkTreeModel *tree_model,
       g_value_take_string (value, str);
       break;
 
+    case THUNAR_UCA_MODEL_COLUMN_RANGE:
+      g_value_set_static_string (value, item->range);
+      break;
+
     case THUNAR_UCA_MODEL_COLUMN_TYPES:
       g_value_set_uint (value, item->types);
       break;
@@ -585,6 +593,7 @@ thunar_uca_model_load_from_file (ThunarUcaModel *uca_model,
   parser.icon_name = g_string_new (NULL);
   parser.command = g_string_new (NULL);
   parser.patterns = g_string_new (NULL);
+  parser.range = g_string_new (NULL);
   parser.description = g_string_new (NULL);
   parser.startup_notify = FALSE;
   parser.unique_id_generated = FALSE;
@@ -599,6 +608,7 @@ thunar_uca_model_load_from_file (ThunarUcaModel *uca_model,
   g_markup_parse_context_free (context);
   g_string_free (parser.description, TRUE);
   g_string_free (parser.patterns, TRUE);
+  g_string_free (parser.range, TRUE);
   g_string_free (parser.command, TRUE);
   g_string_free (parser.icon_name, TRUE);
   g_string_free (parser.unique_id, TRUE);
@@ -623,6 +633,7 @@ thunar_uca_model_item_reset (ThunarUcaModelItem *item)
 {
   /* release the previous values... */
   g_strfreev (item->patterns);
+  g_free (item->range);
   g_free (item->description);
   g_free (item->command);
   g_free (item->name);
@@ -682,6 +693,7 @@ start_element_handler (GMarkupParseContext *context,
           g_string_truncate (parser->unique_id, 0);
           g_string_truncate (parser->command, 0);
           g_string_truncate (parser->patterns, 0);
+          g_string_truncate (parser->range, 0);
           g_string_truncate (parser->description, 0);
           xfce_stack_push (parser->stack, PARSER_ACTION);
         }
@@ -744,6 +756,11 @@ start_element_handler (GMarkupParseContext *context,
           g_string_truncate (parser->patterns, 0);
           xfce_stack_push (parser->stack, PARSER_PATTERNS);
         }
+      else if (strcmp (element_name, "range") == 0)
+        {
+          g_string_truncate (parser->range, 0);
+          xfce_stack_push (parser->stack, PARSER_RANGE);
+        }
       else if (strcmp (element_name, "description") == 0)
         {
           for (n = 0; attribute_names[n] != NULL; ++n)
@@ -853,11 +870,12 @@ end_element_handler (GMarkupParseContext *context,
                                    parser->command->str,
                                    parser->startup_notify,
                                    parser->patterns->str,
+                                   parser->range->str,
                                    parser->types,
                                    0, 0);
 
           /* check if a new id should've been generated */
-          if (exo_str_is_empty (parser->unique_id->str))
+          if (xfce_str_is_empty (parser->unique_id->str))
             parser->unique_id_generated = TRUE;
         }
       else
@@ -894,6 +912,11 @@ end_element_handler (GMarkupParseContext *context,
         goto unknown_element;
       break;
 
+    case PARSER_RANGE:
+      if (strcmp (element_name, "range") != 0)
+        goto unknown_element;
+      break;
+
     case PARSER_DESCRIPTION:
       if (strcmp (element_name, "description") != 0)
         goto unknown_element;
@@ -988,6 +1011,10 @@ text_handler (GMarkupParseContext *context,
       g_string_append_len (parser->patterns, text, text_len);
       break;
 
+    case PARSER_RANGE:
+      g_string_append_len (parser->range, text, text_len);
+      break;
+
     case PARSER_DESCRIPTION:
       if (parser->description_use)
         g_string_append_len (parser->description, text, text_len);
@@ -1116,6 +1143,7 @@ thunar_uca_model_match (ThunarUcaModel *uca_model,
   GList              *lp;
   gint                n_files;
   gint                i, m, n;
+  gint                upper, lower;
   gchar              *path_test;
 
   g_return_val_if_fail (THUNAR_UCA_IS_MODEL (uca_model), NULL);
@@ -1160,6 +1188,22 @@ thunar_uca_model_match (ThunarUcaModel *uca_model,
     {
       /* check if we can just ignore this item */
       item = (ThunarUcaModelItem *) lp->data;
+      upper = n_files;
+      lower = n_files;
+
+      if (item->range != NULL)
+        {
+          gchar **limits = g_strsplit (item->range, "-", 2);
+          if (limits[0] != NULL && limits[1] != NULL)
+            {
+              lower = g_strtod (limits[0], NULL);
+              upper = g_strtod (limits[1], NULL);
+            }
+          g_strfreev (limits);
+        }
+
+      if ((n_files > upper) || (n_files < lower))
+        continue;
       if (!item->multiple_selection && n_files > 1)
         continue;
 
@@ -1331,7 +1375,7 @@ thunar_uca_model_remove (ThunarUcaModel *uca_model,
  * @uca_model          : a #ThunarUcaModel.
  * @iter               : the #GtkTreeIter of the item to update.
  * @name               : the name of the item.
- * @submenu           : the submenu structure in which the item is placed.
+ * @submenu            : the submenu structure in which the item is placed.
  * @unique_id          : a unique ID for the item.
  * @description        : the description of the item.
  * @icon               : the icon for the item.
@@ -1352,6 +1396,7 @@ thunar_uca_model_update (ThunarUcaModel *uca_model,
                          const gchar    *command,
                          gboolean        startup_notify,
                          const gchar    *patterns,
+                         const gchar    *range,
                          ThunarUcaTypes  types,
                          guint           accel_key,
                          GdkModifierType accel_mods)
@@ -1377,6 +1422,8 @@ thunar_uca_model_update (ThunarUcaModel *uca_model,
     item->icon_name = g_strdup (icon);
   if (G_LIKELY (command != NULL && *command != '\0'))
     item->command = g_strdup (command);
+  if (G_LIKELY (range != NULL && *range != '\0'))
+    item->range = g_strdup (range);
   if (G_LIKELY (description != NULL && *description != '\0'))
     item->description = g_strdup (description);
   item->types = types;
@@ -1486,6 +1533,7 @@ thunar_uca_model_save (ThunarUcaModel *uca_model,
                                          "\t<unique-id>%s</unique-id>\n"
                                          "\t<command>%s</command>\n"
                                          "\t<description>%s</description>\n"
+                                         "\t<range>%s</range>\n"
                                          "\t<patterns>%s</patterns>\n",
                                          (item->icon_name != NULL) ? item->icon_name : "",
                                          (item->name != NULL) ? item->name : "",
@@ -1493,6 +1541,7 @@ thunar_uca_model_save (ThunarUcaModel *uca_model,
                                          (item->unique_id != NULL) ? item->unique_id : "",
                                          (item->command != NULL) ? item->command : "",
                                          (item->description != NULL) ? item->description : "",
+                                         (item->range != NULL) ? item->range : "",
                                          patterns);
       fprintf (fp, "%s", escaped);
       g_free (patterns);
@@ -1599,7 +1648,7 @@ thunar_uca_model_parse_argv (ThunarUcaModel *uca_model,
                     goto error;
 
                   dirname = g_path_get_dirname (path);
-                  xfce_append_quoted (command_line, dirname);
+                  xfce_g_string_append_quoted (command_line, dirname);
                   g_free (dirname);
                   g_free (path);
                 }
@@ -1619,7 +1668,7 @@ thunar_uca_model_parse_argv (ThunarUcaModel *uca_model,
                     goto error;
 
                   dirname = g_path_get_dirname (path);
-                  xfce_append_quoted (command_line, dirname);
+                  xfce_g_string_append_quoted (command_line, dirname);
                   g_free (dirname);
                   g_free (path);
                 }
@@ -1629,7 +1678,7 @@ thunar_uca_model_parse_argv (ThunarUcaModel *uca_model,
               if (G_LIKELY (file_infos != NULL))
                 {
                   path = thunarx_file_info_get_name (file_infos->data);
-                  xfce_append_quoted (command_line, path);
+                  xfce_g_string_append_quoted (command_line, path);
                   g_free (path);
                 }
               break;
@@ -1641,7 +1690,7 @@ thunar_uca_model_parse_argv (ThunarUcaModel *uca_model,
                     g_string_append_c (command_line, ' ');
 
                   path = thunarx_file_info_get_name (lp->data);
-                  xfce_append_quoted (command_line, path);
+                  xfce_g_string_append_quoted (command_line, path);
                   g_free (path);
                 }
               break;
