@@ -47,6 +47,20 @@
 
 
 static void          thunar_dialogs_select_filename      (GtkWidget *entry);
+static void          thunar_dialogs_shrink_height        (GtkWidget *dialog);
+
+
+
+static void
+thunar_dialogs_shrink_height (GtkWidget *dialog)
+{
+  gint width;
+  gint height;
+
+  /* Shrinks the dialog to it's minimum height */
+  gtk_window_get_size (GTK_WINDOW (dialog), &width, &height);
+  gtk_window_resize (GTK_WINDOW (dialog), width, 1);
+}
 
 
 
@@ -120,6 +134,7 @@ thunar_dialogs_show_create (gpointer     parent,
       image = g_object_new (GTK_TYPE_IMAGE, "xpad", 6, "ypad", 6, NULL);
       gtk_image_set_from_gicon (GTK_IMAGE (image), icon, GTK_ICON_SIZE_DIALOG);
       gtk_grid_attach (GTK_GRID (grid), image, 0, row, 1, 2);
+      gtk_widget_set_valign (GTK_WIDGET (image), GTK_ALIGN_START);
       g_object_unref (icon);
       gtk_widget_show (image);
     }
@@ -160,6 +175,9 @@ thunar_dialogs_show_create (gpointer     parent,
   if (window != NULL)
     gtk_window_set_transient_for (GTK_WINDOW (dialog), window);
 
+  /* shrink the dialog again, after some filename error was fixed */
+  g_signal_connect_swapped (filename_input, "text-valid", G_CALLBACK (thunar_dialogs_shrink_height), dialog);
+ 
   if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK)
     {
       /* determine the chosen filename */
@@ -261,10 +279,11 @@ thunar_dialogs_show_rename_file (gpointer               parent,
   g_object_unref (G_OBJECT (icon_factory));
 
   image = gtk_image_new_from_pixbuf (icon);
-  gtk_widget_set_margin_start (GTK_WIDGET(image), 6);
-  gtk_widget_set_margin_end (GTK_WIDGET(image), 6);
-  gtk_widget_set_margin_top (GTK_WIDGET(image), 6);
-  gtk_widget_set_margin_bottom (GTK_WIDGET(image), 6);
+  gtk_widget_set_margin_start (GTK_WIDGET (image), 6);
+  gtk_widget_set_margin_end (GTK_WIDGET (image), 6);
+  gtk_widget_set_margin_top (GTK_WIDGET (image), 6);
+  gtk_widget_set_margin_bottom (GTK_WIDGET (image), 6);
+  gtk_widget_set_valign (GTK_WIDGET (image), GTK_ALIGN_START);
   gtk_grid_attach (GTK_GRID (grid), image, 0, row, 1, 2);
   g_object_unref (G_OBJECT (icon));
   gtk_widget_show (image);
@@ -286,8 +305,8 @@ thunar_dialogs_show_rename_file (gpointer               parent,
                             gtk_dialog_get_widget_for_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK));
   g_signal_connect_swapped (filename_input, "text-valid", G_CALLBACK (xfce_filename_input_sensitise_widget),
                             gtk_dialog_get_widget_for_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK));
-
-  /* next row */
+                          
+                            /* next row */
   row++;
 
   gtk_grid_attach (GTK_GRID (grid), GTK_WIDGET (filename_input), 1, row, 1, 1);
@@ -325,6 +344,9 @@ thunar_dialogs_show_rename_file (gpointer               parent,
   g_signal_connect_swapped (G_OBJECT (file), "destroy",
                             G_CALLBACK (gtk_widget_destroy), dialog);
 
+  /* shrink the dialog again, after some filename error was fixed */
+  g_signal_connect_swapped (filename_input, "text-valid", G_CALLBACK (thunar_dialogs_shrink_height), dialog);
+ 
   /* run the dialog */
   response = gtk_dialog_run (GTK_DIALOG (dialog));
   if (G_LIKELY (response == GTK_RESPONSE_OK))
