@@ -39,8 +39,15 @@ G_BEGIN_DECLS;
 
 void     thunar_g_initialize_transformations (void);
 gchar*   thunar_g_strescape                  (const gchar *source);
-gboolean thunar_g_app_info_equal             (gpointer appinfo1,
-                                              gpointer appinfo2);
+gchar*   thunar_g_utf8_normalize_for_search  (const gchar *str,
+                                              gboolean     strip_diacritics,
+                                              gboolean     casefold);
+gboolean thunar_g_app_info_equal             (gpointer     appinfo1,
+                                              gpointer     appinfo2);
+void     thunar_g_object_set_guint_data      (GObject     *object,
+                                              const gchar *key,
+                                              guint        data);
+
 G_END_DECLS;
 
 #endif /* !__THUNAR_GOBJECT_EXTENSIONS_H__ */
