@@ -391,6 +391,7 @@ thunar_job_operation_execute (ThunarJobOperation *job_operation,
   GFile             *parent_dir;
   gchar             *display_name;
   GFile             *template_file;
+  gboolean           execute_failed = FALSE;
 
   _thunar_return_if_fail (THUNAR_IS_JOB_OPERATION (job_operation));
 
@@ -425,11 +426,22 @@ thunar_job_operation_execute (ThunarJobOperation *job_operation,
             thunar_file_list = g_list_append (thunar_file_list, thunar_file);
           }
 
-        /* perform permanent deletion without warning, because we can bring back the file with
-         * an undo or a redo (depending on whether a redo or an undo caused the deletion) */
-        thunar_application_unlink_files (application, NULL, thunar_file_list, TRUE, FALSE);
+        if (thunar_file_list == NULL)
+          {
+            execute_failed = TRUE;
+          }
+        else
+          {
+            execute_failed = thunar_application_unlink_files (application, NULL, thunar_file_list, TRUE, TRUE);
+            g_list_free_full (thunar_file_list, g_object_unref);
+          }
 
-        thunar_g_list_free_full (thunar_file_list);
+        if (execute_failed)
+          {
+            *error = g_error_new (G_FILE_ERROR,
+                                  G_FILE_ERROR_AGAIN,
+                                  "Failed to execute operation");
+          }
         break;
 
       case THUNAR_JOB_OPERATION_KIND_MOVE:
@@ -665,12 +677,35 @@ thunar_job_operation_restore_from_trash (ThunarJobOperation  *operation,
     }
 
   /* set up a hash table for the files we deleted */
-  files_trashed = g_hash_table_new_full (g_file_hash, (GEqualFunc) g_file_equal, NULL, NULL);
+  files_trashed = g_hash_table_new_full (g_file_hash, (GEqualFunc) g_file_equal, g_object_unref, NULL);
 
   /* add all the files that were deleted in the hash table so we can check if a file
    * was deleted as a part of this operation or not in constant time. */
   for (GList *lp = operation->target_file_list; lp != NULL; lp = lp->next)
-    g_hash_table_add (files_trashed, lp->data);
+  {
+    GFile *parent = g_file_get_parent (lp->data);
+    gchar *real_path = NULL;
+    
+    /* Try to resolve symlinks, otherwise Gfiles wont match */
+    /* (All files located in trash have symlinks resolved) */
+    if (parent != NULL)
+      {
+        gchar *real_path_parent = NULL;
+        gchar *basename = g_file_get_basename (lp->data);
+        real_path_parent = thunar_g_file_get_resolved_path (parent);
+        g_object_unref (parent);
+        if (real_path_parent != NULL && basename != NULL)
+          real_path = g_build_filename (real_path_parent, basename, NULL);
+        g_free (basename);
+        g_free (real_path_parent);
+      }
+
+    if (real_path != NULL)
+      g_hash_table_add (files_trashed, g_file_new_for_path (real_path));
+    else
+      g_hash_table_add (files_trashed, g_object_ref (lp->data));
+    g_free (real_path);
+  }
 
   /* iterate over the files in the trash, adding them to source and target lists of
    * the files which are to be restored and their original paths */
