@@ -89,6 +89,7 @@ enum
   PROP_MISC_DATE_CUSTOM_STYLE,
   PROP_EXEC_SHELL_SCRIPTS_BY_DEFAULT,
   PROP_MISC_FOLDERS_FIRST,
+  PROP_MISC_FOLDER_ITEM_COUNT,
   PROP_MISC_FULL_PATH_IN_TAB_TITLE,
   PROP_MISC_FULL_PATH_IN_WINDOW_TITLE,
   PROP_MISC_HORIZONTAL_WHEEL_NAVIGATES,
@@ -687,6 +688,19 @@ thunar_preferences_class_init (ThunarPreferencesClass *klass)
                             TRUE,
                             EXO_PARAM_READWRITE);
 
+  /**
+   * ThunarPreferences:misc-folder-item-count
+   *
+   * Tells when the size column of folders should show the number of containing files
+   **/
+  preferences_props[PROP_MISC_FOLDER_ITEM_COUNT] =
+      g_param_spec_enum ("misc-folder-item-count",
+                         "MiscFolderItemCount",
+                         NULL,
+                         THUNAR_TYPE_FOLDER_ITEM_COUNT,
+                         THUNAR_FOLDER_ITEM_COUNT_NEVER,
+                         EXO_PARAM_READWRITE);
+
   /**
    * ThunarPreferences:misc-full-path-in-tab-title:
    *
@@ -1010,7 +1024,7 @@ thunar_preferences_class_init (ThunarPreferencesClass *klass)
    **/
   preferences_props[PROP_MISC_IMAGE_PREVIEW_FULL] =
     g_param_spec_enum ("misc-image-preview-mode",
-                       "MiscImagePreviewMoe",
+                       "MiscImagePreviewMode",
                        NULL,
                        THUNAR_TYPE_IMAGE_PREVIEW_MODE,
                        THUNAR_IMAGE_PREVIEW_MODE_EMBEDDED,
@@ -1146,7 +1160,7 @@ thunar_preferences_class_init (ThunarPreferencesClass *klass)
                         "MiscCompactViewMaxChars",
                         NULL,
                         G_MININT, G_MAXINT,
-                        50,
+                        100,
                         EXO_PARAM_READWRITE);
 
   /**
