@@ -28,10 +28,6 @@
 
 
 
-static ThunarRenamerPair *thunar_renamer_pair_copy (ThunarRenamerPair *renamer_pair) G_GNUC_MALLOC;
-
-
-
 GType
 thunar_renamer_pair_get_type (void)
 {
@@ -93,7 +89,7 @@ thunar_renamer_pair_new (ThunarFile  *file,
  *
  * Return value: the newly allocated copy of @renamer_pair.
  **/
-static ThunarRenamerPair*
+ThunarRenamerPair*
 thunar_renamer_pair_copy (ThunarRenamerPair *renamer_pair)
 {
   _thunar_return_val_if_fail (renamer_pair != NULL, NULL);
@@ -161,3 +157,49 @@ thunar_renamer_pair_list_free (GList *renamer_pair_list)
 }
 
 
+
+/**
+ * thunar_renamer_pair_compare_ascending
+ * @pair_a : first pair
+ * @pair_b : second pair
+ *
+ * Based on GCompareFunc
+ * This function can be used as a comparator to sort a #Glist of
+ * #ThunarRenamerPair in ascending order of their name.
+ **/
+int
+thunar_renamer_pair_compare_ascending (const void *pair_a,
+                                       const void *pair_b)
+{
+  ThunarRenamerPair *a, *b;
+  ThunarFile *file_a, *file_b;
+  a = (ThunarRenamerPair *) pair_a;
+  b = (ThunarRenamerPair *) pair_b;
+  file_a = a->file;
+  file_b = b->file;
+  return thunar_file_compare_by_name (file_a, file_b, TRUE);
+}
+
+
+
+/**
+ * thunar_renamer_pair_compare_descending
+ * @pair_a : first pair
+ * @pair_b : second pair
+ *
+ * Based on GCompareFunc
+ * This function can be used as a comparator to sort a #Glist of
+ * #ThunarRenamerPair in descending order of their name.
+ **/
+int
+thunar_renamer_pair_compare_descending (const void *pair_a,
+                                        const void *pair_b)
+{
+  ThunarRenamerPair *a, *b;
+  ThunarFile *file_a, *file_b;
+  a = (ThunarRenamerPair *) pair_a;
+  b = (ThunarRenamerPair *) pair_b;
+  file_a = a->file;
+  file_b = b->file;
+  return -1 * thunar_file_compare_by_name (file_a, file_b, TRUE);
+}
\ No newline at end of file
