@@ -1254,7 +1254,18 @@ thunar_shortcuts_view_context_menu (ThunarShortcutsView *view,
         }
     }
 
-  if (file != NULL)
+  if (device != NULL && !thunar_device_is_mounted (device))
+    {
+      g_object_set (G_OBJECT (view->action_mgr), "selected-device", device, NULL);
+      thunar_action_manager_append_menu_item (view->action_mgr, GTK_MENU_SHELL (context_menu), THUNAR_ACTION_MANAGER_ACTION_OPEN, TRUE);
+      thunar_action_manager_append_menu_item (view->action_mgr, GTK_MENU_SHELL (context_menu), THUNAR_ACTION_MANAGER_ACTION_OPEN_IN_TAB, TRUE);
+      thunar_action_manager_append_menu_item (view->action_mgr, GTK_MENU_SHELL (context_menu), THUNAR_ACTION_MANAGER_ACTION_OPEN_IN_WINDOW, TRUE);
+      xfce_gtk_menu_append_separator (GTK_MENU_SHELL (context_menu));
+      thunar_menu_add_sections (context_menu, THUNAR_MENU_SECTION_MOUNTABLE);
+      if (thunar_device_is_mounted (device))
+        thunar_menu_add_sections (context_menu, THUNAR_MENU_SECTION_PROPERTIES);
+    }
+  else if (file != NULL)
     {
       files = g_list_append (NULL, file);
       g_object_set (G_OBJECT (view->action_mgr), "current-directory", file, NULL);
@@ -1289,17 +1300,6 @@ thunar_shortcuts_view_context_menu (ThunarShortcutsView *view,
       thunar_action_manager_append_menu_item (view->action_mgr, GTK_MENU_SHELL (context_menu), THUNAR_ACTION_MANAGER_ACTION_OPEN_IN_TAB, TRUE);
       thunar_action_manager_append_menu_item (view->action_mgr, GTK_MENU_SHELL (context_menu), THUNAR_ACTION_MANAGER_ACTION_OPEN_IN_WINDOW, TRUE);
     }
-  else if (device != NULL)
-    {
-      g_object_set (G_OBJECT (view->action_mgr), "selected-device", device, NULL);
-      thunar_action_manager_append_menu_item (view->action_mgr, GTK_MENU_SHELL (context_menu), THUNAR_ACTION_MANAGER_ACTION_OPEN, TRUE);
-      thunar_action_manager_append_menu_item (view->action_mgr, GTK_MENU_SHELL (context_menu), THUNAR_ACTION_MANAGER_ACTION_OPEN_IN_TAB, TRUE);
-      thunar_action_manager_append_menu_item (view->action_mgr, GTK_MENU_SHELL (context_menu), THUNAR_ACTION_MANAGER_ACTION_OPEN_IN_WINDOW, TRUE);
-      xfce_gtk_menu_append_separator (GTK_MENU_SHELL (context_menu));
-      thunar_menu_add_sections (context_menu, THUNAR_MENU_SECTION_MOUNTABLE);
-      if (thunar_device_is_mounted (device))
-        thunar_menu_add_sections (context_menu, THUNAR_MENU_SECTION_PROPERTIES);
-    }
   else
       g_error("Unknown type");
 
