@@ -92,7 +92,10 @@ gboolean
 thunar_side_pane_get_show_hidden (ThunarSidePane *side_pane)
 {
   _thunar_return_val_if_fail (THUNAR_IS_SIDE_PANE (side_pane), FALSE);
-  return (*THUNAR_SIDE_PANE_GET_IFACE (side_pane)->get_show_hidden) (side_pane);
+  if (THUNAR_SIDE_PANE_GET_IFACE (side_pane)->get_show_hidden != NULL)
+    return (*THUNAR_SIDE_PANE_GET_IFACE (side_pane)->get_show_hidden) (side_pane);
+
+  return FALSE;
 }
 
 
@@ -110,6 +113,7 @@ thunar_side_pane_set_show_hidden (ThunarSidePane *side_pane,
                                   gboolean        show_hidden)
 {
   _thunar_return_if_fail (THUNAR_IS_SIDE_PANE (side_pane));
-  (*THUNAR_SIDE_PANE_GET_IFACE (side_pane)->set_show_hidden) (side_pane, show_hidden);
+  if (THUNAR_SIDE_PANE_GET_IFACE (side_pane)->set_show_hidden != NULL)
+    (*THUNAR_SIDE_PANE_GET_IFACE (side_pane)->set_show_hidden) (side_pane, show_hidden);
 }
 
