@@ -136,6 +136,13 @@ struct _ThunarStandardViewClass
   /* Internal action signals */
   gboolean     (*delete_selected_files) (ThunarStandardView *standard_view);
 
+  /* Set the CellLayoutDataFunc to be used */
+  void        (*cell_layout_data_func)    (GtkCellLayout     *layout,
+                                           GtkCellRenderer   *cell,
+                                           GtkTreeModel      *model,
+                                           GtkTreeIter       *iter,
+                                           gpointer           data);
+
   /* The name of the property in ThunarPreferences, that determines
    * the last (and default) zoom-level for the view classes (i.e. in
    * case of ThunarIconView, this is "last-icon-view-zoom-level").
