@@ -657,13 +657,12 @@ ttj_copy_file (ThunarTransferJob  *job,
     }
   else
     {
-      if (add_to_operation)
+      if (add_to_operation && thunar_job_get_log_mode (THUNAR_JOB (job)) == THUNAR_OPERATION_LOG_OPERATIONS)
         {
           if (copy_flags & G_FILE_COPY_OVERWRITE)
             thunar_job_operation_overwrite (operation, target_file);
 
-          if (thunar_job_get_log_mode (THUNAR_JOB (job)) == THUNAR_OPERATION_LOG_OPERATIONS)
-            thunar_job_operation_add (operation, source_file, target_file);
+          thunar_job_operation_add (operation, source_file, target_file);
         }
       return TRUE;
     }
