@@ -157,6 +157,8 @@ void                      thunar_window_toolbar_swap_items                  (Thu
 XfceGtkActionEntry*       thunar_window_get_action_entries                  (void);
 
 void                      thunar_window_reconnect_accelerators              (ThunarWindow        *window);
+void                      thunar_window_focus_view                          (ThunarWindow        *window,
+                                                                             GtkWidget           *view);
 
 
 G_END_DECLS;
